"""."""

# 定义抽取结果的名字
OUTPUT = "result.csv"

# 状态机状态
START = 0  # 开始状态
TITLE = 1  # 抽取文书title信息
TYPE = 2  # 抽取类型信息
NUMBER = 3  # 案号信息
YUANGAO = 4  # 原告信息
BEIGAO = 5  # 被告信息
PARTY = 10  # 新版，当事人，取代原告，被告，第三人
THIRD_PERSON = 6  # 第三人信息
CONTENT = 7  # 抽取文书内容信息
FOOTER = 8  # 抽取文书落款信息
END = 9  # 结束信息

CASE_DOMAIN = ["民事", "行政", "刑事", "执行"]  # 案件类型
LAW_TYPE = ["裁决书", "判决书", "裁定书", "调解书"]  # 文书类型
PARTIES_STOP = ["申诉人", "反诉原告", "原告人", "原告",
                "上诉单位", "本诉原告", "上诉人", "公诉机关", "再审申请人", "起诉人", "申请人",
                "申请再审人", "自诉人", "复议申请人", "附带民事诉讼原告人", "申请执行人", "申请追加人",
                "解除保全申请人", "原告1", "原告2", "原告3", "异议人", "申请复议人"]
PARTIES_YG = ["原审上诉人", "申诉人", "原审原告", "反诉原告", "一审原告", "原告人",
              "上诉单位", "本诉原告", "上诉人", "公诉机关", "再审申请人", "起诉人", "申请人",
              "申请再审人", "自诉人", "复议申请人", "附带民事诉讼原告人", "申请执行人", "申请追加人",
              "解除保全申请人", "再审上诉人", "原告1", "原告2", "原告3", "原告一", "原告二",
              "原告三", "原告",
              "异议人", "申请复议人", "申请执行机关", "申请执行", "申请复议人", "案外人"]
PARTIES_BG = ["原审被上诉人", "被申诉人", "被上诉人", "被诉人", "再审被申请人", "被申请人",
              "原上诉人", "被起诉人", "本诉被告", "原公诉机关", "原审被告", "反诉被告",
              "一审被告", "被告人", "附带民事诉讼被告人", "被执行人", "被申请追加人", "罪犯",
              "再审被上诉人", "被告1", "被告2", "被告3", "被告一", "被告二", "被告三", "被告"]
PARTIES_DSR = ["一审第三人", "原审第三人", "反诉第三人", "第三人", "第三",
               "一审原告、二审上诉人", "一审原告、二审被上诉人", "一审被告、二审上诉人", "一审被告、二审被上诉人",
               "一审第三人、二审上诉人", "一审第三人、二审被上诉人"]

PARTIES = []  # 当事人信息
PARTIES.extend(PARTIES_YG)
PARTIES.extend(PARTIES_BG)
PARTIES.extend(PARTIES_DSR)

LEGAL = ["定代表人", "法等代表人", "法定代笔人", "法定代表人", "法定代表", "法定代理人",
         "法定代人", "法定借助人", "法人代表人", "法人代表"]
PRINCIPAL = ["全权代表", "授权代表", "授权经理人", "授权签署人", "授权签字代表",
             "授权签字人", "授权人", "义乌办事处首席代表", "代表人", "负责人", "委托代理", "代理人",
             "诉讼代表人", "委托代表人"]  # 授权代表
OTHERS = ["监护人", "经营者", "投资人", "执行合伙企业事务的合伙人", "执行合伙人", "执行合伙事务合伙人",
          "执行事务合伙人", "专家辅助人", "翻译人员", "法定代理人", "业主"]  # 其他
PROXY = ["辩护人", "委托代理人", "委托人", "委托人理人", "诉讼代理人",
         "委托地利人", "委托大理人", "委托诉讼代理人", "委托代付"]  # 诉讼代理人
RELATIVES = []
RELATIVES.extend(PROXY)
RELATIVES.extend(PRINCIPAL)
RELATIVES.extend(OTHERS)
RELATIVES.extend(LEGAL)

ROLES = ["经营者", "审判长", "代理审判员", "书记员", "人民陪审员"]  # 所有角色
ROLES.extend(PARTIES)
ROLES.extend(RELATIVES)
AFFAIR = ["经营者", "法定代表人", "委托代理人"]
FOOTER_ROLE = ["审判长", "代理审判长", "审判员", "代理审判员",
               "人民陪审员", "法官助理", "书记员", "速录员"]  # 落款处角色信息
PUNCTUATION = set([u"，u", u"。", u"？", u"！", u"：u", u"；"])
PUNCTUATION_ALL = set([u"，", u"。", u"？", u"！", u"：",
                       u"；", ",", "?", "!", ":", ";"])
LINE_COUNT = 0
DICT = {}  # 字典
CHINESE_NUM = {"一": 1, "二": 2, "三": 3, "四": 4, "五": 5, "六": 6, "七": 7, "八": 8,
               "九": 9, "十": 10, "两": 2, "十一": 11, "十二": 12, "十三": 13,
               "十四": 14, "十五": 15}
NUMBERS = ["一", "二", "三", "四", "五", "六", "七", "八", "九",
           "十", "1", "2", "3", "4", "5", "6", "7", "8", "9"]

# 正则
JUDGE_PATTERN = "(裁决|裁定|判决)(如下|)(:|：)"  # 判决如下
YEAR_MONTH_DATE = "(\\d+)年(\\d+)月(\\d+)(日|)"  # 人物出生日期
# 案号正则
ANHAO = "(\(|\[|（|【|〔|（|)(\d+)(\)|\]|】|〕|）|)(.{3,40})([\d、\-—xX]+)(号)(之一)?"
# 案号正则
YISHENANHAO = "(\(|\[|（|【|〔|（|)(\d+)(\)|\]|】|〕|）|)(.{5,40})(\d+)"
YISHENANHAO += "(号)(之一)?(民事|行政|)(判决|裁定|)"
ANHAO_YEAR = "\d{4}"  # 案号里年份
TRADEMARK_ID = "商评字(\(|\[|（|【|〔)(\d+)(\)|\]|）|】|〕)第(\d+)号"  # 商评字
PATENT_ID = "(专利复审委员会|知识产权局)(.+)第((\d|\.)+)号专利"  # 专利号
FOOTER_YEAR_MONTH_DATE = "(.+)年(.+)月(.+)日"  # 落款日期
# 第三人和被告/原告share共同代理人的情况, %s是角色
COMMON_ROLES_PATTERN1 = '(被告|原告|第三人|上诉人|被上诉人|原审被告|原审原告|原审第三人|)'
COMMON_ROLES_PATTERN1 += '(和|,|，|、|与|)(被告|原告|第三人|上诉人|被上诉人|原审被告|原审原告|原审第三人|)'
COMMON_ROLES_PATTERN1 += '(|之|的)(共同|)%s'
# 上述(以上)x人共同代表人
COMMON_ROLES_PATTERN2 = '(一|二|两|三|四|五|六|七|八|九|十])?(人|%s)(|之|的)%s'
YISHEN_MIN_PAN = ["(驳回(.{0,30})(诉讼|本诉)请求|的(诉讼|本诉)请求不予支持)", "驳回原告诉讼请求"]
YISHEN_MIN_CAI = []
YISHEN_MIN_CAI_1 = ["(按撤诉处理|按(.{0,20})(撤回|撤销)(起诉|反诉|本诉|诉讼)处理)", "按撤诉处理"]
YISHEN_MIN_CAI_2 = ["((撤回|撤销)(.{0,10})(起诉|反诉|本诉|诉讼)|撤诉)", "撤诉"]
YISHEN_MIN_CAI_3 = ["(驳回(.{0,20})起诉|诉讼|反诉|本诉)", "驳回起诉"]
YISHEN_MIN_CAI_4 = ["(不予受理|不予立案)", "不予受理"]
YISHEN_MIN_CAI_5 = ["中止(诉讼|审理)", "中止诉讼"]
YISHEN_MIN_CAI_6 = ["恢复(诉讼|审理)", "恢复审理"]
YISHEN_MIN_CAI_7 = ["驳回(.{0,10})管辖(权|)异议", "驳回管辖权异议"]
YISHEN_MIN_CAI_8 = ["(扣押|冻结|查封|保全|禁令)", "保全程序"]
YISHEN_MIN_CAI_9 = ["本案(指定|(交|)由)(,{0,10})人民法院(审理|管辖)", "指定审理"]
YISHEN_MIN_CAI_10 = ["并入(.{1,30})号案", "并案审理"]
YISHEN_MIN_CAI_11 = ["(另立案号|另案审理|分(为|立)(二|两|三|四|五|六|七|八|九|十)(件|)案)", "分案审理"]
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_1)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_2)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_3)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_4)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_5)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_6)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_7)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_8)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_9)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_10)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_11)
# 正则 Jokers
PATENT_NUMBER = '((ZL|CN|)[ 0-9０－９Xx×Ｘｘ＊*]{8,12}\.[0-9０－９XxＸｘ×＊×])'
TRADEMARK_NUMBER = '(诉争商标|引证商标)?\w*第([0-9]+)号[^，。；、：]*?商标\w*'

ERSHEN_MIN_PAN = []
ERSHEN_MIN_PAN_1 = ["撤销(.{1,10})号(民事判决|原审判决|一审判决)", "撤销一审判决"]
ERSHEN_MIN_PAN_2 = ["(维持原判|维持原审判决|维持一审判决|维持+号民事判决)", "维持一审判决"]
ERSHEN_MIN_PAN.append(ERSHEN_MIN_PAN_1)
ERSHEN_MIN_PAN.append(ERSHEN_MIN_PAN_2)
ERSHEN_XING_PAN = []
ERSHEN_XING_PAN_1 = ["(驳回上诉(.+)维持一审判决|维持原审判决)", "维持一审判决"]
ERSHEN_XING_PAN.append(ERSHEN_XING_PAN_1)

ERSHEN_CAI = []
ERSHEN_XING_CAI_1 = ["(维持原裁定|维持一审裁定|维持原审裁定)", "维持一审裁定"]
ERSHEN_XING_CAI_2 = ["撤销(.+)裁定", "撤销一审裁定"]
ERSHEN_XING_CAI_3 = ["(撤销(.+)判决)(.+)发回(.+)(重审|重新审理)", "撤销一审判决，发回一审重新审理"]
ERSHEN_XING_CAI_4 = ["(撤销(.+)判决)(.+)(驳回(.+)起诉)", "撤销一审判决，驳回原告起诉"]
ERSHEN_XING_CAI_5 = ["(撤回(.+)起诉|撤回(.+)上诉|撤诉)", "撤诉"]
ERSHEN_XING_CAI_6 = ["(恢复诉讼|恢复审理)", "恢复审理"]
ERSHEN_CAI.append(ERSHEN_XING_CAI_1)
ERSHEN_CAI.append(ERSHEN_XING_CAI_2)
ERSHEN_CAI.append(ERSHEN_XING_CAI_3)
ERSHEN_CAI.append(ERSHEN_XING_CAI_4)
ERSHEN_CAI.append(ERSHEN_XING_CAI_5)
ERSHEN_CAI.append(ERSHEN_XING_CAI_6)
# 关键词
SUMMARY = ["不服", "受理", "本院", "原告", "被告"]  # 总结段落的启发词语
END_JUDGE = ["提起上诉", "受理费"]  # 判决结果结束标志
# 民族正则
NATION = "^(汉|哈尼|保安|白|阿昌|布朗|布依|朝鲜|达斡尔|傣|德昂|东乡|侗|独龙"
NATION += "|鄂伦春|俄罗斯|鄂温克|高山|仡佬|哈萨克|赫哲|回|基诺|景颇|京|柯尔克孜|拉祜|"
NATION += "珞巴|僳僳|黎|满|毛南|门巴|蒙古|苗|仫佬|纳西|怒|普米|羌|撒拉|畲|水|塔吉克|"
NATION += "塔塔尔|土家|土|佤|维吾尔|乌孜别克|锡伯|瑶|彝|裕固|藏|壮)族?$"
# 职务正则
POSITION = "副?总?(董事长|无业|新闻资源合作专员|登记注册科科员|法律事务科科员|合伙事务执行人|技术资产所有人|\
总制片人经营人|产业部负责人|法律事务人员|IT工程师|保护科科长|党委副书记|法定代表人|法规股股长|法务部经理|\
法政科科员|高级工程师|个体工商户|合伙执行人|技术部部长|迁西代理商|商标代理人|事务协调员|首席财务官|首席技术官|\
首席运营官|首席执行官|授权签字人|药品注册员|职业摄影师|专利代理人|专利工程师|财务人员|财务总监|代表理事|\
党委书记|党组书记|法律顾问|法律顺间|法务专员|副董事长|副理事长|副调研员|副研究员|副总代表|高级记者|工作人员|\
管理部长|高级管理人员|管理人员|行政副总|行政管理|行政人员|行政助理|行政专员|技术副总|技术人员|技术总监|经销商户|律师助理|\
内容总监|企管人员|人事专员|社长助理|实习律师|事务专员|首席摄影|授权代表|授权官员|维权专员|文职人员|项目经理|\
销售代表|运营总监|支部书记|执行懂事|指导老师|总裁助理|总工程师|总机械师|总设计师|财务长|承包人|出资人|代理人|\
代理商|法律部负责人|负责人|复审员|副部长|副区长|副书记|副团长|副镇长|副政委|助理副总裁|副总裁|工程师|管理员|合伙人|技术员|经营者|\
理事长|配镜师|评审员|评审审查员|审查员|投资人|业务员|营业员|执行官|总编辑|总干事|总指挥|编辑|法律部部长|\
助理部长|部长|财务|厂长|场长|处长|\
代表|店员|店长|店主|执行董事|董事|队长|法律|法人|法务|副理|副总|评审干部|退休干部|干部|工人|股东|股长|\
知识产权顾问|顾问|雇员|馆长|行长|会计|会员|会长\
|监事|教师|教授|经理|局长|科员|科长|课长|矿长|老师|理事|律师|助理秘书|秘书|区长|社长|所长|台长|团长|网管|文员|县长\
|乡长|校长|协理|药师|业主|园长|员工|院长|运营|站长|镇长|职工|法律部职员|职员|主编|主管|助理主任|\
主任|主席|专利代理人助理|助理|住持|专务|\
专员|总编|总裁|总监|组长|CE0|CEO|PaulBuysse长和AlbrechtDeGraeve董事\
|财务副董事长、首席财务官、财务主管兼秘书|公司法律顾问与商标及版权事务知识产权主管|\
副总裁、法律及知识产权事务助理总法律顾问|公司董事会助理秘书及公司助理首席法律顾问|\
法务部和事务部高级副总裁、法律顾问及秘书|助理秘书、高级副总裁兼首席知识产权顾问|\
董事长董事兼现金及衍生产品市场部负责人|副总法律兼交易和战略部首席知识产权顾问|\
授权代表、知识产权专利申请及诉讼部主管|副总裁、总法律顾问、首席法务官兼秘书|\
执行董事兼环球银行及资本市场业务主管|副总裁、总法律顾问、首席合规官兼秘书|\
副总裁、副总法律顾问兼助理董事会秘书|副总法律兼交易与策略首席知识产权顾问|\
第一副总裁、知识产权总顾问及助理秘书|法律顾问、商标及版权处知识产权负责人|\
董事会助理秘书及公司助理首席法律顾问|高级副总裁、首席法律顾问及董事会秘书|\
助理秘书、高级副总裁及知识产权总顾问|高级副总裁、首席法律顾问、董事会秘书|\
副总法律和交易与策略首席知识产权顾问|周吉宜兼以上十五位之共同委托代理人|副总裁、副总法律顾问兼公司助理秘书|\
执行副总裁兼首席行政官和总法律顾问|副总裁、副总法律顾问兼公司秘书助理|法务和企业联合部副总裁兼授权签字人|\
高级董事首席知识产权和诉讼法律顾问|事务高级副总裁、总法律顾问兼秘书|执行副总裁兼总法律顾问和公司秘书|\
财务副总裁兼首席财务官兼助理秘书|副总兼首席交易和战略知识产权顾问|董事兼现金及衍生产品市场部负责人|\
副总裁、助理总法律顾问兼助理秘书|高级副总裁、总法律顾问兼公司秘书|执行副总裁、总法律顾问兼公司秘书|\
高级副总裁、法务总监兼董事会秘书|高级副总裁兼集团总顾问、集团法务|董事会秘书及公司助理首席法律顾问|\
商标、法律及知识产权事务法律顾问|知识产权及标准部(中国区)负责人|首席财政官、财务主管及执行副总裁|\
首席财务官、运营副总裁及法律代表|首席法务官、法律总顾问及公司秘书|高级副总裁、法律总顾问及公司秘书|\
高级执行副总裁及知识产权管理经理|商业开发、法律及知识产权事务总监|董事会助理秘书及助理首席法律顾问|\
部门主任和公司名称或商标法律主管|法律企业、EMEA和APAC主管|助理公司秘书和知识产权助理总顾问|\
副总裁、副总法律顾问兼助理秘书|法律顾问兼全球商标实践组负责人|副总裁、助理法律顾问兼助理秘书|\
高级副总裁-法律顾问兼公司秘书|副总裁、副总法律顾问兼总裁助理|董事兼副社长执行董事兼财务总监|\
副总裁、副总法律顾问兼秘书助理|亚太、大中华及南非区首席执行官|副总裁、董事会秘书及总法律顾问|\
公司管理委员会及执行理事会主席|专利操作法律及知识产权事务总监|执行副总裁、法律总监及公司秘书|\
助理秘书及知识产权副总法律顾问|知识产权助理法律顾问及助理秘书|全球知识产权交易和战略高级顾问|\
职务资深法律顾问和知识产权主管|执行副总裁、商务法务和助理秘书|副总法律顾问兼法务审计部部长|\
高级副总裁、总法律顾问兼秘书|副总裁兼知识产权副总法律顾问|副总裁兼首席知识产权法律顾问|\
副总裁、总法律顾问兼公司秘书|高级副总裁-法律总顾问兼秘书|授权代表人兼商标事务法律顾问|\
会主席、首席执行官兼常务董事|财务和行政副总裁兼首席执行官|高级副总裁、法律总顾问兼秘书|\
副总裁(法律事务)兼公司秘书|高级副总裁、总顾问兼公司秘书|高级副总裁兼全球副总法律顾问|\
全球公司副总裁、总顾问兼秘书|财务副总裁、首席财务官兼主管|管理委员会董事长兼首席执行官|\
执行副总裁、总法律顾问兼秘书|董事执行官兼研究开发部总经理|执行副总裁兼总法律顾问及秘书|\
CRB‘‘LLC经理兼合伙人|上海古籍出版社副社长兼副总编|副总裁、法律总顾问兼公司秘书|高级副总裁及知识产权法律顾问|\
助理总法律顾问及首席商标律师|副总裁及知识产权副总法律顾问|副执行官、法律顾问及公司秘书|\
总理及原住民事务和糖业部部长|职务律师、知识产权部长及董事|高级副总裁、法律总顾问及秘书|\
职务副总法律顾问及执法副总裁|执行副总裁、总法律顾问及秘书|高级副总裁、总法律顾问及秘书|\
知识产权及标准部中国区负责人|执行副总裁和首席法务官及秘书|高级副总裁、总顾问及公司秘书|\
首席法律顾问助理和商标部主管|投票代理人和高级知识产权律师|公共事务和法律事务部执行总监|\
高级知识产权顾问和集群负责人|执行副总裁、公司总顾问和秘书|研究合作伙伴和技术转移部经理|\
副总裁、助理总顾问和助理秘书|副总裁、总法律顾问和公司秘书|助理总法律顾问和商标部门主管|\
总经理助理兼规划发展部部长|助理秘书兼全球反盗版副总裁|副本部长兼知识产权中心所长|高级副总裁、法务总监兼秘书|\
副总裁兼商标总法律顾问助理|秘书兼职业道德与合规副总裁|副总裁、副总顾问兼助理秘书|副总裁兼知识产权副法律顾问|\
助理秘书长兼商标与品牌总监|副总裁、总法律顾问兼总秘书|董事长、总经理兼首席执行官|顾问、高级副总裁兼公司秘书|\
运营执行副总裁兼法律总顾问|代表取缔役会长兼社长CEO|副总裁、法律顾问兼执行秘书|高级执行副总裁兼首席财务官|\
代表取缔役社长兼首席执行官|法律事务副总裁兼总法律顾问|职务集团董事长兼首席执行官|副总裁兼北美公司职能总顾问|\
北美地区董事长兼首席执行官|北美地区董事长兼首席运营官|高级副总裁兼全球总法律顾问|副总裁-法律兼公司助理秘书|\
行政副总裁、法律顾问兼秘书|副总兼首席知识产权法律顾问|执行副总裁、法律总监及秘书|专利、商标及许可证部总经理|\
第一副总裁及知识产权总顾问|财政、行政、采购及操作总监|金融、产品及区域高级副总裁|执行副总裁、总顾问及总秘书|\
专利法律及知识产权事务总监|高级副总裁、法律顾问及秘书|副总知识产权顾问及助理秘书|职务法律顾问及知识产权主管|\
副总法律顾问及知识产权总监|知识产权及诉讼副总法律顾问|专利及商标部门经理和代理人|总经理及广东保信事务所律师|\
公司法律董事及法定公司秘书|法律及公司事务部执行副总裁|公司和医疗事务部执行副总裁|高级财务副总监和首席财务官|\
资深法律顾问和知识产权主管|知识产权法副总裁和助理秘书|首席运营官和公司战略执行官|高级副总裁和首席法律执行官|\
副总裁兼首席知识产权顾问|副总裁兼总法律和税务顾问|助理秘书兼助理法律总顾问|执行副总裁、总顾问兼秘书|\
副总裁兼首席知识产权律师|法务执行副总裁兼公司秘书|执行董事兼质量保证部部长|秘书、总顾问兼高级副总裁|\
副总裁兼商业食品法律顾问|财务总监、秘书兼财务主管|副总裁、法律总顾问兼秘书|副总裁、总顾问兼公司秘书|\
高级副总裁、总顾问兼秘书|集团执行董事兼首席执行官|助理总法律顾问兼助理秘书|总经理(法务)兼公司秘书|\
董事会副主席兼首席执行官|党委书记、董事长兼总经理|高级执行总裁兼首席执行官|商标及版权顾问兼授权代表|\
法务副总裁兼首席专利顾问|高级副总裁兼首席法律顾问|副总裁兼知识产权法律顾问|副总裁兼副国际总法律顾问|\
助理秘书长兼副总法律顾问|知识产权全球总监兼代理人|合伙人兼美国区总法律顾问|高级副董事长兼总法务顾问|\
副总裁、首席财务官兼主管|董事该公司董事长兼总经理|总裁、首席执行官兼董事长|高级副总裁兼知识产权顾问|\
副总裁、助理总顾问兼秘书|执行(常务)董事兼总经理|大中华地区及亚太区代理人|集团财务及行政管理总经理|\
助理总法律顾问及助理秘书|集团首席法务官及公司秘书|律师、知识产权部长及董事|副总法律顾问及执行副总裁|\
商务及法律事务高级副总裁|高级副总裁及高级法律顾问|副总法律顾问及执法副总裁|顾问及全球商标运营组主管|\
技术管理和标准化部负责人|高级公司法律顾问和代理人|普通合伙人和独立法定代表|欧洲、中东和非洲运营经理|\
副总裁、总法律顾问和秘书|副总法律顾问和高级副总裁|知识产权律师和法定代理人|法律和公司事务高级副总裁|\
高级副总裁和公司法律顾问|品牌执行和商标法高级总监|董事长、首席执行官和主席|公司秘书和职业操守副总裁|\
副总裁、法律总顾问和秘书|总顾问和法律事务部负责人|战略发展顾问兼法律顾问|法定代表人兼实际经营者|\
委副书记兼办公室主任|副总工程师兼机械部主任|高级副总裁兼助理总顾问|法务副总裁兼总法律顾问|\
执行副总裁兼总法律顾问|高级副总裁兼首席财务官|职务高级副总裁兼总顾问|董事会主席兼首席执行官|\
董事局主席兼首席执行官|副总法律顾问兼助理秘书|共同创办人兼首席运营官|副总裁、秘书兼财务主管|\
集团首席执行官兼董事长|高级副总裁兼总法律顾问|助理法律顾问兼助理秘书|法律总顾问兼董事会秘书|\
助理秘书兼高级专利经理|高级副总裁兼法律总顾问|副总裁兼总法律顾问助理|执行副总裁兼首席财务官|\
副总裁、法律总监兼秘书|集团副总裁兼总法律顾问|副总裁兼法务及公司秘书|副总裁兼助理法律总顾问|\
副总裁兼助理总法律顾问|副总裁兼首席法律执行官|总法律顾问兼董事会秘书|资深法律顾问兼助理秘书|\
助理秘书兼高级法律顾问|高级副总裁兼公司总顾问|财务副总裁兼首席财务官|助理总顾问兼高级副总裁|\
营销总监兼授权高级职员|职务董事长兼首席执行官|公司行政总裁兼执行董事|秘书兼(美洲)法务顾问|\
执行副总裁兼首席运营官|高级副总裁兼董事会秘书|首席行政官兼总法律顾问|副总裁兼董事会常务主席|\
公司副总裁兼法律总顾问|公司副主席及助理总顾问|首席执行官及首席财务官|销售、市场及技术副总裁|\
法律顾问及知识产权律师|董事会主席及首席执行官|执行副总裁及法律总顾问|首席商标及版权顾问律师|\
法律董事及法定公司秘书|商标及知识产权部总顾问|副总裁及高级总法律顾问|高级副总裁及总法律顾问|\
董事总经理及法律总顾问|知识产权及许可部总经理|高级副总裁及法律总顾问|副总裁及知识产权总顾问|\
执行合伙人及总法律顾问|人力资源及法律部副总裁|法定代表人及实际经营者|副教授及原告法定代表人|\
董事会主席和首席执行官|总法律顾问和董事会秘书|专利、商标和许可总经理|首席执行官和董事会主席|\
知识产权部和商标部主任|欧洲、中东和非洲区主管|秘书和道德与守法副总裁|法律顾问和知识产权主管|\
副总裁、法律和助理秘书|高级副总裁和公司总顾问|高级法律顾问和商标经理|董事会董事和授权签字人|\
全球知识产权和执行总监|董事会成员和授权签字人|知识产权和打击仿冒经理|首席法律和知识产权总监|\
销售和营销副总裁、董事|公共关系部和财务部经理|高级副总裁和总法律顾问|商务和法务部高级副总裁|\
总经理助理兼法律顾问|高级副总裁兼公司秘书|副总裁兼助理法律顾问|副总裁兼副总法律顾问|常务董事兼首席执行官|\
高级副总裁兼副总顾问|总顾问、副总裁兼秘书|助理总法律顾问兼秘书|董事局主席兼集团总裁|副总裁兼首席专利顾问|\
副董事长兼首席执行官|执行副总裁兼法务总监|总法律顾问兼公司秘书|董事会主席兼行政总裁|公司秘书兼法定代表人|\
公司秘书兼高级副总裁|集团副总裁兼法律顾问|副总裁兼首席法律顾问|副总裁兼福总法律顾问|执行副总裁兼代表董事|\
助理秘书兼助理总顾问|副总裁、总顾问兼秘书|高级副总裁兼助理秘书|副总裁兼知识产权顾问|副总裁兼高级商标顾问|\
法律顾问兼董事会秘书|集团总顾问兼公司秘书|财务总监兼高级副总裁|董事局主席兼行政总裁|副总裁兼高级法律顾问|\
执行副总裁兼法律顾问|首席运营官兼公司秘书|副总裁兼法律顾问助理|、副总经理兼执行董事|执行副总裁兼财务主管|\
特别副总裁兼助理秘书|副总裁兼诉讼事务主管|副总裁兼副法律总顾问|法律顾问兼法务副总裁|高级副总裁兼法律顾问|\
邯郸县兼庄乡退休干部|助理总兼首席照明顾问|助理总顾问兼助理秘书|兼副总经理、执行董事|董事兼授权市场总经理|\
副会长兼任首席执行官|副总经理兼法律总顾问|副董事长兼总律师助理|系公司执行董事兼经理|副总裁兼助理公司秘书|\
副总裁兼秘书兼总顾问|职务执行董事兼总经理|副总裁及法律总监助理|商标及版权总法律顾问|知识产权及认证部经理|\
法务及知识产权部部长|助理总顾问及助理秘书|知识产权及法务部职员|法务及知识产权部主管|副董事长及首席执行官|\
法务及知识产权总经理|财务及成本控制部主管|商标、设计及域名主管|专利商标及许可总经理|集团首席法务官及秘书|\
知识产权及战略部部长|执行董事及总务部部长|副总裁及法律总裁助理|特许销售总经理及董事|副总裁及知识产权顾问|\
创新及企业关系部主任|商标、市场及广告总监|首席法务官及公司秘书|副总裁及副总法律顾问|高级副总裁及法务总监|\
许可及商业事务副总裁|集团总顾问及公司秘书|商务及法务高级副总裁|执行副总裁及财务总监|知识产权及认证部董事|\
总法律顾问及助理秘书|财务及行政执行副总裁|营销及商业部法律总监|职务许可及合同代理人|法律及公司事务部主管|\
法律及知识产权部主管|公司总顾问及公司秘书|销售及医务执行副总裁|管理董事及授权签字人|高级工程师及全权代表|\
市场营销及通讯部经理|高级副总裁及公司秘书|律师、商标及版权经理|技术中心及服务部董事|副总裁和副总法律顾问|\
首席运营官和公司秘书|抚顺市天和地板厂业主|副总裁、总顾问和秘书|涂料和精加工部副总裁|法务总监和总经理秘书|\
商务和法律事务副总裁|法律和商业事务副总裁|商标和知识产权总顾问|系佳和购物中心经营者|执行董事和高级副总裁|\
高级副总裁和法务总监|法律总顾问和公司秘书|高级副总裁和副总顾问|董事主席和首席执行官|集团首席法务官和秘书|\
商标和版权总法律顾问|知识产权和战略副总裁|法定代表人兼总经理|总裁助理兼法律顾问|副总经理兼技术总监|\
副董事长兼总工程师|总经理兼法定代表人|总经理兼党委副书记|副总裁兼授权签字人|副总裁兼总顾问助理|\
董事长兼首席执行官|总经理兼首席执行官|首席执行官兼董事长|副总裁兼首席执行官|总裁兼副总法律顾问|\
副总裁兼法律总顾问|副总裁兼总法律顾问|副总裁兼助理总顾问|法律顾问兼助理秘书|执行副总裁兼总顾问|\
副总裁兼副专利顾问|法务部主任兼代理人|副总裁兼首席财务官|助理部长兼法律顾问|董事总经理兼总顾问|\
高级副总裁兼总顾问|副总顾问兼助理秘书|公司副总裁兼总顾问|商标经理兼授权代表|董事会主席兼总经理|\
执行副总裁兼董事长|总经理兼总法律顾问|法定代表兼授权代表|副总裁兼副法律顾问|副会长兼首席执行官|\
高级副总裁兼总经理|首席财务官兼副总裁|助理秘书兼高级律师|代表兼常务执行董事|副总裁秘书兼总顾问|\
董事长兼首席运营官|总裁兼行政总执行官|助理顾问兼助理秘书|集团副总裁兼总顾问|助理秘书兼高级顾问|\
法律顾问兼公司秘书|法律顾问兼代理律师|副董事长兼财务总监|职务董事长兼总经理|重庆兼善事务所律师|\
职务执行董事兼经理|总编辑兼常务副社长|副总裁兼总经理秘书|法务主管兼公司秘书|驻以色列经理兼董事|\
副社长兼首席执行官|总经理兼首席财务官|系执行董事兼总经理|公司顾问兼公司秘书|职务董事长兼CEO|\
首席商标兼副总顾问|副主席兼首席执行官|总法律顾问兼副总裁|财务总监兼公司秘书|行政总裁兼执行董事|\
副总裁兼法定代表人|副总裁兼代理总顾问|副总裁兼总专利顾问|资深副总裁兼总顾问|执行董事兼任总经理|\
副总裁及首席执行官|首席商标及版权顾问|董事长及首席执行官|助理秘书及高级顾问|高级副总裁及总顾问|\
副总顾问及助理秘书|执行副总裁及总顾问|授权代表及财务总监|商标及版权事务总监|副总裁及首席运营官|\
知识产权及许可总监|执行董事及机要秘书|执行副及亚太区总裁|民事保护及诉讼总监|秘书部长及法务总监|\
法务及合规部副总裁|首席运营官及总顾问|董事总经理及总顾问|助理部长及高级顾问|财务总监及公司秘书|\
法律及公司事务经理|副总裁及总税务顾问|副总经理及财务主管|清算组成员及负责人|国际销售和服务经理|\
内部管理和审计经理|技术开发和保护经理|商标经理和助理秘书|销售和市场部副总裁|商标和产品法律顾问|\
商标和版权法律顾问|资深副总裁和总顾问|首席行政官和代理人|副总裁和总法律顾问|业务发展和执行董事|\
法律顾问和知产主管|首席执行官和董事长|知识产权部长和董事|法务和知识产权部长|集团顾问和法律顾问|\
广告和品牌管理顾问|财务总监和销售经理|执行副总和财务总监|商标和版权事务总监|董事会成员和代理人|\
实际控制人、总经理|法人代表兼总经理|会计兼办公室主任|董事长兼党委书记|总经理兼总工程师|董事长兼总工程师|\
销售部经理兼厂长|副总经理兼负责人|执行董事兼总经理|股东兼实际经营者|总法律顾问兼秘书|总裁兼首席执行官|\
主席兼首席执行官|董事兼总法律顾问|首席执行官兼总裁|高级副总裁兼秘书|秘书兼法律总顾问|副总裁兼助理秘书|\
副总裁兼审计主任|副总裁兼财务主管|会主席兼执行董事|执行副总裁兼秘书|总经理兼执行董事|副总裁兼法务主管|\
副总裁兼法律顾问|总裁兼首席运营官|副董事长兼总顾问|副总裁兼副总顾问|副总裁兼商标律师|副会长兼代表理事|\
法律总顾问兼秘书|总经理兼党委书记|董事长兼执行总裁|律师兼法律总顾问|董事兼首席执行官|秘书兼总法律顾问|\
总顾问兼公司秘书|副总裁兼专利律师|代表理事兼副会长|副总裁兼专利顾问|代理董事兼总经理|副总裁兼公司秘书|\
公司副总裁兼董事|公司董事兼总经理|法务副总裁兼秘书|代表董事兼总经理|社长兼首席执行官|秘书兼商务副总裁|\
副总裁兼秘书助理|副董事长兼总经理|秘书兼助理总顾问|副总裁兼法律总监|董事会成员兼秘书|副总裁兼首席顾问|\
总裁兼首席财务官|公司副总裁兼秘书|首席法律官兼秘书|集团总裁兼董事长|副主席兼首席顾问|职务董事兼总经理|\
副总裁兼法务总监|首席法务官兼秘书|法律部主任兼董事|副总裁兼商标顾问|秘书兼首席财务官|首席商标兼总顾问|\
高级副总裁兼总监|首席执行官兼董事|公司兼职工作人员|总裁兼董事会主席|首席财务官兼董事|首席财务官兼秘书|\
董事长兼研发总监|首席执行官兼社长|职务总经理兼董事|总裁及首席执行官|专利及商标代理人|执行副总裁及秘书|\
副总裁及法律顾问|总经理及授权代表|副总裁以及总顾问|副社长及代表董事|副总裁及助理秘书|总顾问及公司秘书|\
董事及授权签字人|首席执行官及董事|首席法务官及秘书|替任董事及副总裁|公司董事及总经理|执行董事及总经理|\
财务及运营负责人|销售及营销副总裁|专利代理人及律师|法定代表人及股东|专利代理人及职员|副总裁及法务总监|\
董事会主席及总裁|秘书及总法律顾问|副总裁及公司秘书|会主席及常务董事|秘书及首席财务长|总顾问和公司秘书|\
代理人和授权官员|主席和首席执行官|公司董事和总经理|商标和著作权总监|执行董事和总经理|总经理和法定代表|\
法律和税务部总监|董事和总法律顾问|首席执行官和总裁|精益眼镜店的员工|常务董事和代理人|董事和共同代理人|\
董事长兼总经理|执行董事兼经理|前台兼行政助理|股东兼副总经理|董事兼副总经理|法务兼信息专员|副总经理兼监事|\
副总裁兼总顾问|厂长兼技术总监|主席兼行政总裁|董事兼高级顾问|秘书兼财务主管|律师兼授权官员|总经理兼董事长|\
代理经理兼董事|董事兼助理秘书|董事长兼CEO|董事兼高级律师|董事兼执行秘书|合伙人兼总经理|副总裁兼总经理|\
法务兼商务总监|副社长兼总编辑|社长兼执行董事|CEO兼董事长|秘书兼法务总监|公司顾问兼秘书|法律顾问兼秘书|\
公司律师兼董事|顾问兼常务董事|代表董事兼总裁|秘书兼法律总监|主管兼助理秘书|董事兼财务经理|代表董事兼社长|\
董事长兼执行官|董事兼法务主管|财务主管兼秘书|经理兼执行董事|执行董事兼院长|总裁兼执行董事|所有人兼总经理|\
副长兼常务董事|唯一董事兼总裁|CE0兼董事长|党组书记兼局长|财务及行政主管|商标及版权主管|专利及许可部长|\
助理总法律顾问|公司顾问及秘书|市场及销售总监|副总裁及总经理|副总裁及总顾问|行政及财务总监|营销及服务总监|\
律师及律师助理|律师及实习律师|商标及版权经理|董事长及总经理|管理及销售经理|经理及公司秘书|总经理及副总裁|\
商标及外观顾问|资深顾问及律师|总经理及董事长|执行董事及经理|销售及市场经理|商标及设计法务|亿家酒店经营者|\
人事及财务主管|商标和外观主管|董事和授权代表|商标和版权顾问|财务和审计总监|工业和商务总监|行政和审计总监|\
代表董事和社长|副总裁和总经理|行政和财务总监|董事和法律顾问|商标和外观顾问|商标和版权经理|秘书和法务总监|\
董事和公司秘书|科学和运营总监|主席和执行总裁|执行总裁和董事|法律顾问和秘书|专利和商标专员|精益眼镜店员工|\
总经理和董事长|董事兼总经理|股东兼总经理|副总裁兼秘书|总经理兼董事|董事长兼厂长|董事长兼总裁|董事长兼社长|\
合伙人兼经理|长兼常务董事|总裁兼董事长|董事兼副总裁|长兼专务董事|社长兼总编辑|董事长兼校长|社长兼总经理|\
总顾问兼秘书|长兼代表董事|总裁兼CEO|副总裁兼董事|董事长兼经理|董事兼副主席|董事及总经理|董事长及总裁|\
董事及副总裁|总顾问及秘书|副总裁及秘书|个体户经营者|社长及总编辑|总经理及董事|律师及其助理|股东及负责人|\
销售部经营者|副主席和总裁|总裁和总经理|销售中心业主|信息中心主任|董事兼经理|个体工商户|兼法律顾问|股东兼员工|\
会长兼社长|董事兼秘书|董事兼总裁|主管兼秘书|总裁兼秘书|总裁兼董事|社长兼主编|社长兼总编|书记兼院长|及常务董事|\
董事及经理|董事及总裁|董事及秘书|主席及董事|个体经营者|法定代表人|律师及助理|主管工程师|总裁及董事|主管和董事|\
运营部经理|执行副总裁|总裁和秘书|总经理助理|仓库经营者|实际经营者|法制股股长|办公室主任|供销部长|商标评审员|\
助理总法律顾问|法务主管|法务副总裁|法务总监|法务经理|法务职员|法务董事|法务部长|\
法律事务部主管|法律事务部副总裁|法律事务部总监|法律事务部经理|法律事务部职员|法律事务部董事|法律事务部部长)$"
