"""."""
from distutils.core import setup

setup(name='zcb_gz',
      version='1.1',
      author='Jokers',
      author_email='hlxstc680@gmail.com',
      url='https://www.python.org/jokers/distutils-sig/',
      packages=[
        'zcb_gz', 'zcb_gz.jokers', 'zcb_gz.ronghui',
        'zcb_gz.ronghui.Money'],
      )
